Learn R Programming

ottr (version 1.5.3)

collector_varname: The name of the active collector variable in collector_env

Description

The name of the active collector variable in collector_env

Usage

collector_varname

Arguments

Format

An object of class character of length 1.