Learn R Programming

ottr (version 1.5.3)

run_autograder: Grade an R script against test files in a directory

Description

Run autograder in a Gradescope container and return the results as a properly-formatted JSON string.

Usage

run_autograder(script_path, ignore_errors, test_dir)

Value

The JSON string

Arguments

script_path

The path to the script

ignore_errors

Whether to ignore errors thrown while executing the script

test_dir

A directory of tests to glob from

Examples

Run this code
if (FALSE) {
run_autograder("hw01.R", "ABC123", TRUE, "tests")
}

Run the code above in your browser using DataLab