Learn R Programming

ottr (version 1.5.3)

running_on_jupyter: Determine whether this R session is running on Jupyter.

Description

Determine whether this R session is running on Jupyter by checking for a CommManager in IRkernel.

Usage

running_on_jupyter()

Arguments

Value

A boolean indicating whether IRkernel is running.

Examples

Run this code
if (FALSE) {
running_on_jupyter()
}

Run the code above in your browser using DataLab