powered by
Run autograder in a Gradescope container and return the results as a properly-formatted JSON string.
run_autograder(script_path, ignore_errors, test_dir)
The JSON string
The path to the script
Whether to ignore errors thrown while executing the script
A directory of tests to glob from
if (FALSE) { run_autograder("hw01.R", "ABC123", TRUE, "tests") }
Run the code above in your browser using DataLab